# Athanasius

> python CLI to archive files

[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)

## Usage

### Archive Files/Directories

```bash
# multiple files
ath file1.py *.txt
```
```bash
# specified output archive name file
ath mydir/ -o bobby
```

### Extract

```bash
ath -e archive_filename.ath
```
